@@ -2,7 +2,7 @@ import re
 
 from setuptools import find_packages, setup
 
-version = re.search('^__version__\s*=\s*"(.*)"', open("cognite/client/__init__.py").read(), re.M).group(1)
+version = re.search('^__version__\s*=\s*"(.*)"', open("cognite/client/_version.py").read(), re.M).group(1)
 
 with open("README.md", "r") as fh:
     long_description = fh.read()
@@ -18,6 +18,7 @@ setup(
     author="Erlend Vollset",
     author_email="erlend.vollset@cognite.com",
     install_requires=["requests>=2.21.0,<3.0.0", "requests_oauthlib==1.3.0"],
+    extras_require={"pandas": ["pandas"], "geo": ["geopandas==0.10.*", "shapely==1.*"]},
     python_requires=">=3.5",
     packages=["cognite." + p for p in find_packages(where="cognite")],
     include_package_data=True,
